%{?scl:%scl_package libomp}
%{!?scl:%global pkg_name %{name}}
%global devtoolset_name devtoolset-9

#%%global rc_ver 6
%global baserelease 3
%global libomp_srcdir openmp-%{version}%{?rc_ver:rc%{rc_ver}}.src


%ifarch ppc64le
%global libomp_arch ppc64
%else
%global libomp_arch %{_arch}
%endif

Name: %{?scl_prefix}libomp
Version: 11.0.1
Release: %{baserelease}%{?rc_ver:.rc%{rc_ver}}%{?dist}
Summary: OpenMP runtime for clang

License: NCSA
URL: http://openmp.llvm.org
Source0: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{libomp_srcdir}.tar.xz
Source1: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{libomp_srcdir}.tar.xz.sig
Source2: tstellar-gpg-key.asc
Source3: run-lit-tests
Source4: lit.fedora.cfg.py

Patch0: 0001-CMake-Make-LIBOMP_HEADERS_INSTALL_PATH-a-cache-varia.patch

BuildRequires: %{?scl:%{devtoolset_name}-}gcc
BuildRequires: %{?scl:%{devtoolset_name}-}gcc-c++
BuildRequires: %{?scl_prefix}cmake
BuildRequires: elfutils-libelf-devel
BuildRequires: perl
BuildRequires: perl-Data-Dumper
BuildRequires: perl-Encode
BuildRequires: libffi-devel

Requires: elfutils-libelf%{?isa}

# libomp does not support s390x.
ExcludeArch: s390x

%description
OpenMP runtime for clang.

%package devel
Summary: OpenMP header files
Requires: %{?scl_prefix}clang-resource-filesystem%{?isa} = %{version}

%description devel
OpenMP header files.

%package test
Summary: OpenMP regression tests
Requires: %{?scl_prefix}libomp%{?isa} = %{version}-%{release}
Requires: %{?scl_prefix}libomp-devel%{?isa} = %{version}-%{release}
Requires: %{?scl_prefix}clang
Requires: %{?scl_prefix}llvm
Requires: gcc
Requires: gcc-c++
Requires: %{?scl_prefix}python2-lit

%description test
OpenMP regression tests

%prep
%autosetup -n %{libomp_srcdir} -p1

%build
mkdir -p _build
cd _build

%cmake .. \
    -DCMAKE_C_COMPILER=/opt/rh/%{devtoolset_name}/root/usr/bin/gcc\
    -DCMAKE_CXX_COMPILER=/opt/rh/%{devtoolset_name}/root/usr/bin/g++\
	-DLIBOMP_INSTALL_ALIASES=OFF \
	-DLIBOMP_HEADERS_INSTALL_PATH:PATH=%{_libdir}/clang/%{version}/include \
%if 0%{?__isa_bits} == 64
	-DOPENMP_LIBDIR_SUFFIX=64 \
%else
	-DOPENMP_LIBDIR_SUFFIX= \
%endif

%make_build


%install
%make_install -C _build

# Test package setup
%global libomp_srcdir %{_datadir}/libomp/src/
%global libomp_testdir %{libomp_srcdir}/runtime/test/
%global lit_cfg %{libomp_testdir}/%{_arch}.site.cfg.py
%global lit_fedora_cfg %{_datadir}/libomp/lit.fedora.cfg.py

install -d %{buildroot}%{libomp_srcdir}/runtime
cp -R runtime/test  %{buildroot}%{libomp_srcdir}/runtime
cp -R runtime/src  %{buildroot}%{libomp_srcdir}/runtime
# remove patch file generated by Patch0
rm %{buildroot}%{libomp_srcdir}/runtime/src/CMakeLists.txt.orig

# Generate lit config files.  Strip off the last line that initiates the
# test run, so we can customize the configuration.
head -n -1 _build/runtime/test/lit.site.cfg >> %{buildroot}%{lit_cfg}

# Install custom fedora config file
cp %{SOURCE4} %{buildroot}%{lit_fedora_cfg}

# Patch lit config files to load custom fedora config
echo "lit_config.load_config(config, '%{lit_fedora_cfg}')" >> %{buildroot}%{lit_cfg}

# Install test script
install -d %{buildroot}%{_libexecdir}/tests/libomp
install -m 0755 %{SOURCE3} %{buildroot}%{_libexecdir}/tests/libomp

# Remove static libraries with equivalent shared libraries
rm -rf %{buildroot}%{_libdir}/libarcher_static.a

# Remove arch-dependent python files
find %{buildroot}/%{_datadir}/libomp -name '*.py[co]' -delete

%files
%license LICENSE.txt
%{_libdir}/libomp.so
%{_libdir}/libomptarget.so
%ifnarch %{arm}
%{_libdir}/libarcher.so
%endif
%ifnarch %{arm} %{ix86}
%{_libdir}/libomptarget.rtl.%{libomp_arch}.so
%endif

%files devel
%{_libdir}/clang/%{version}/include/omp.h
%ifnarch %{arm}
%{_libdir}/clang/%{version}/include/omp-tools.h
%{_libdir}/clang/%{version}/include/ompt.h
# FIXME: This is probably wrong.  Seems like LIBOMP_HEADERS_INSTALL may
# not be respected.
%{_includedir}/ompt-multiplex.h
%endif

%files test
%{_datadir}/libomp
%{_libexecdir}/tests/libomp/

%changelog
* Tue Jan 26 2021 Serge Guelton - 11.0.1-3
- Remove python-generated files from test source

* Tue Jan 26 2021 Serge Guelton - 11.0.1-2
- Remove a shipped backup file

* Wed Jul 22 2020 <sguelton@redhat.com> - 10.0.1-1
- 10.0.1 Release

* Fri Jul 17 2020 sguelton@redhat.com - 10.0.0-3
- Correctly remove byte-compiled Python files

* Fri Jul 17 2020 sguelton@redhat.com - 10.0.0-2
- Remove byte-compiled Python files

* Wed Jul 8 2020 sguelton@redhat.com - 10.0.0-1
- 10.0.0 Release

* Mon Jan 27 2020 Tom Stellard <tstellar@redhat.com> - 9.0.1-1
- 9.0.1 Release

* Wed Aug 28 2019 sguelton@redhat.com - 8.0.1-3
- Remove __cmake hack

* Thu Aug 1 2019 sguelton@redhat.com - 8.0.1-2
- Update cmake dependency

* Mon Jul 29 2019 sguelton@redhat.com - 8.0.1-1
- 8.0.1 Release

* Thu Jan 10 2019 Tom Stellard <tstellar@redhat.com> - 7.0.1-2
- Rebuild for i686

* Wed Jan 09 2019 Tom Stellard <tstellar@redhat.com> - 7.0.1-1
- 7.0.1 Release

* Tue Sep 11 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-7
- Don't install patch backup files

* Tue Sep 11 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-6
- Drop libatomic test dependency on ppc64le

* Tue Sep 11 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-5
- Fix lit test failures on ppc64

* Mon Sep 10 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-4
- Remove gcc tests from runtest.sh

* Mon Sep 10 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-3
- Fix path in runtest.sh

* Sat Sep 08 2018 Edjunior Barbosa Machado <emachado@redhat.com> - 6.0.1-2
- Depend on python2 instead of python3

* Wed Jul 11 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-1
- 6.0.1 Release

* Mon Jan 15 2018 Tom Stellard <tstellar@redhat.com> - 5.0.1-2
- Rebuild to include i686

* Thu Dec 21 2017 Tom Stellard <tstellar@redhat.com> - 5.0.1-1
- 5.0.1 Release.

* Wed Jun 21 2017 Tom Stellard <tstellar@redhat.com> - 4.0.1-1
- 4.0.1 Release.

* Wed Jun 07 2017 Tom Stellard <tstellar@redhat.com> - 4.0.0-3
- Rename libopenmp->libomp

* Fri May 26 2017 Tom Stellard <tstellar@redhat.com> - 4.0.0-2
- Disable build on s390x

* Mon May 15 2017 Tom Stellard <tstellar@redhat.com> - 4.0.0-1
- Initial version.
